@@ -2,7 +2,7 @@ import time
 import os
 import configparser
 from apscheduler.schedulers.background import BackgroundScheduler
-import dynamicdnsrecord
+from src import dynamicdnsrecord
 
 config = configparser.ConfigParser()
 config.read('../config.ini')
